@@ -2,7 +2,7 @@
 
 from .leadlist import LeadList
 from .top100prospectleads import Top100ProspectLeads
-from .top10targetsfortheweek import Top10TargetsForWeek
+from .top10targetsfortheweek import Top10TargetsForTheWeek
 from .TodayTarget import TodayTarget
 from .game_loop import GameLoop
 from .bant import BANT
